@@ -7,8 +7,8 @@ from ..util import ToDenseWarning
 __all__ = []
 
 
-@B.dispatch([AbstractMatrix])
-def concat(*elements, axis=0):
+@B.dispatch
+def concat(*elements: AbstractMatrix, axis=0):
     if structured(*elements):
         elements_str = ", ".join(map(str, elements[:3]))
         if len(elements) > 3:
@@ -17,4 +17,4 @@ def concat(*elements, axis=0):
             f"Concatenating {elements_str}: converting to dense.",
             category=ToDenseWarning,
         )
-    return Dense(B.concat(*(B.dense(el) for el in elements), axis=axis))
+    return Dense(B.concat(*(B.dense(el) for el in elements), axis=axis))
\ No newline at end of file
