@@ -7,10 +7,10 @@ from ..util import ToDenseWarning
 __all__ = []
 
 
-@B.dispatch(AbstractMatrix)
-def isnan(a):
+@B.dispatch
+def isnan(a: AbstractMatrix):
     if structured(a):
         warn_upmodule(
             f'Applying "isnan" to {a}: converting to dense.', category=ToDenseWarning
         )
-    return B.isnan(B.dense(a))
+    return B.isnan(B.dense(a))
\ No newline at end of file
