@@ -1,3 +1,5 @@
+from typing import Union
+
 import lab as B
 
 from ..matrix import AbstractMatrix
@@ -10,23 +12,23 @@ from ..shape import assert_square
 __all__ = []
 
 
-@B.dispatch(AbstractMatrix)
-def logdet(a):
+@B.dispatch
+def logdet(a: AbstractMatrix):
     return 2 * B.logdet(B.cholesky(a))
 
 
-@B.dispatch({Diagonal, LowerTriangular, UpperTriangular})
-def logdet(a):
+@B.dispatch
+def logdet(a: Union[Diagonal, LowerTriangular, UpperTriangular]):
     return B.sum(B.log(B.diag(a)))
 
 
-@B.dispatch(Woodbury)
-def logdet(a):
+@B.dispatch
+def logdet(a: Woodbury):
     return B.logdet(a.diag) + B.logdet(a.lr.middle) + B.logdet(B.schur(a))
 
 
-@B.dispatch(Kronecker)
-def logdet(a):
+@B.dispatch
+def logdet(a: Kronecker):
     assert_square(
         a.left, f"Left factor of {a} must be square to compute the log-determinant."
     )
@@ -36,4 +38,4 @@ def logdet(a):
     )
     n = B.shape(a.left)[0]
     m = B.shape(a.right)[0]
-    return m * B.logdet(a.left) + n * B.logdet(a.right)
+    return m * B.logdet(a.left) + n * B.logdet(a.right)
\ No newline at end of file
