@@ -3,7 +3,7 @@ import lab as B
 __all__ = []
 
 
-@B.dispatch(object, object)
+@B.dispatch
 def ratio(a, b):
     """Compute the ratio between two positive-definite matrices.
 
@@ -18,4 +18,4 @@ def ratio(a, b):
     return B.sum(B.iqf_diag(b, chol))
 
 
-B.ratio = ratio
+B.ratio = ratio
\ No newline at end of file
