@@ -7,12 +7,12 @@ from ..util import ToDenseWarning
 __all__ = []
 
 
-@B.dispatch(AbstractMatrix, B.Int, B.Int)
-def reshape(a, rows, cols):
+@B.dispatch
+def reshape(a: AbstractMatrix, rows: B.Int, cols: B.Int):
     warn_upmodule(f"Converting {a} to dense for reshaping.", category=ToDenseWarning)
     return Dense(B.reshape(B.dense(a), rows, cols))
 
 
-@B.dispatch(Dense, B.Int, B.Int)
-def reshape(a, rows, cols):
-    return Dense(B.reshape(a.mat, rows, cols))
+@B.dispatch
+def reshape(a: Dense, rows: B.Int, cols: B.Int):
+    return Dense(B.reshape(a.mat, rows, cols))
\ No newline at end of file
