@@ -11,46 +11,46 @@ from ..triangular import LowerTriangular, UpperTriangular
 __all__ = []
 
 
-@B.dispatch(Zero)
-def transpose(a):
+@B.dispatch
+def transpose(a: Zero):
     return Zero(a.dtype, a.cols, a.rows)
 
 
-@B.dispatch(Dense)
-def transpose(a):
+@B.dispatch
+def transpose(a: Dense):
     return Dense(B.transpose(a.mat))
 
 
-@B.dispatch(Diagonal)
-def transpose(a):
+@B.dispatch
+def transpose(a: Diagonal):
     return a
 
 
-@B.dispatch(Constant)
-def transpose(a):
+@B.dispatch
+def transpose(a: Constant):
     return Constant(a.const, a.cols, a.rows)
 
 
-@B.dispatch(LowerTriangular)
-def transpose(a):
+@B.dispatch
+def transpose(a: LowerTriangular):
     return UpperTriangular(B.transpose(a.mat))
 
 
-@B.dispatch(UpperTriangular)
-def transpose(a):
+@B.dispatch
+def transpose(a: UpperTriangular):
     return LowerTriangular(B.transpose(a.mat))
 
 
-@B.dispatch(LowRank)
-def transpose(a):
+@B.dispatch
+def transpose(a: LowRank):
     return LowRank(a.right, a.left, B.transpose(a.middle))
 
 
-@B.dispatch(Woodbury)
-def transpose(a):
+@B.dispatch
+def transpose(a: Woodbury):
     return Woodbury(B.transpose(a.diag), B.transpose(a.lr))
 
 
-@B.dispatch(Kronecker)
-def transpose(a):
-    return Kronecker(B.transpose(a.left), B.transpose(a.right))
+@B.dispatch
+def transpose(a: Kronecker):
+    return Kronecker(B.transpose(a.left), B.transpose(a.right))
\ No newline at end of file
